.comment POSITION PRINTER TO START ON 4TH LINE FOR 66 LINE (11 INCH)
.comment PAPER. THE 60 LINES PRINTED SHOULD BE VERTICALLY CENTERED
.comment ON THE PAGE, WITH 3 LINE VERTICAL MARGINS TOP AND BOTTOM.
.comment
.comment   THE TITLE PAGE IS LAID OUT SO THAT THE TITLE WILL
.comment   SHOW THROUGH A "WINDOW" COVER SUCH AS IS USED ON
.comment   DEC DOCUMENTS.
.nhd
.uc
.ps 58,80
.lm 8
.rm 72
#
.s 26
.c ;DECUS C LANGUAGE SYSTEM
.s 2
.c ;P/OS User Interface Services
.c ;CTEX Library
.s 2
.c ;by
.s
.c ;Bob Denny _& Kristina Hamm
.s 13
.p 2, 1, 3
.ap
.pg
.hd mixed
.t  ;########P/OS User Interface Library
.st ;########June##1984

.chapter INTRODUCTION
.lm 8
.rm 72
.t  ;########P/OS User Interface Library
.st ;########June##1984
 This document describes the interface library for accessing
most P/OS "user interface" services.  These services are provided
by the CTEX (a.k.a. CTAB) "shell" of P/OS.  They include many
services for menus, printing, message board, and escape sequence
decoding.

The library is called CTEX.OLB and is located in the usual P/OS
develoment library directory (e.g., [001005] on the PRO).  The interface
maps fairly closely to the equivalent given in the toolkit manual, except
for the parameters and other things explicitly noted.  These
modules are basically intended for P/OS Version 2.0 although most
will work on Version 1.7.

.note
Many of the routines in this library the calling program
must be linked against
the POSRES cluster library, and in some cases, the RMSRES library as well.
Most imortantly, you MUST use the RMS version of the standard I/O
library.
Consult toolkit documentation for linking requirements.
.en

As of now, there are no "H" files for status values. The status codes can be
referenced in the Professional Developer's Toolkit Reference
Manual.

You will notice that all of the directive titles include a 'P_$'.  These are to
diffferentiate them from other C directives.  In the CTEX library, P_$FOO
would map to FOO.  These 'P_$' are essential in calling the CTEX directives.

Also the order of passing the parameters has been modified for consistency
and convenience.

.note
When passing 'null' strings, do NOT pass a NULL or 0, rather, pass "".
.en

For the most part, the routines in this library
provide a convenient run-time interface to the user interface
services from C. In keeping with the efforts to baseline and
standardize the common C runtime library functions, the CTEX
library is distributed separately.



.chapter FUNCTION DESCRIPTIONS
.lm 8
.rm 72
.t  ;########P/OS User Interface Library
.st ;########June##1984
 Each function description consists of the function name, the English
name, parameter type definitions in C, and the function call format
in C. The corresponding description in the Toolkit Reference
Manual should be used as a primary reference. If
system symbols are involved, there will be a header file for use
with the C function, and it will be specified in the function
description.
 The following is a list of the executive services and their
function calls provided by the CTEX library.
.s
.nf
	Callable Print Services			P_$CPRNT
	Display Dynamic Menu			P_$DMENU
	Pack Dynamic Single-Choice Menu		P_$DPACK
	Fatal Error				P_$FATLER
	Get Keystroke				P_$GETKEY
	Close Current Help Frame File		P_$HCLOSE
	Display Help Frame			P_$HELP
	Open Help File				P_$FILE
	Display Help Frame _& Set New Default	P_$HFRAME
	Close Current Menu Frame File		P_$MCLOSE
	Display Single-Choice Menu Frame	P_$MENU
	Open Menu Frame File			P_$MFILE
	Load Static Menu Frame      		P_$MFRAME
	Pack Multiple-Choice Menu Frame		P_$MMENU
	Pack Multiple-Choice Menu		P_$MPACK
	Unpack Menu Buffer			P_$MUNPK
	Post Message On Message Board		P_$MSGBRD
	New File Specification Menu 		P_$NEWFIL
	File Selection Menu			P_$OLDFIL
	Wait For 'Resume" Key			P_$WTRES

.f
.lm 8.rm 72.nhy

.no autosubtitle .style headers 3,0,0
.pg.uc.ps 58,80.lm 8.rm 72
.hd
.hd mixed
.head mixed

.st ########p$cprnt#Callable Print Services
.pg
.hl 1 ^&Callable Print Services\&
.s 2
.c ;***********
.c ;* p$cprnt *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$cprnt -- Callable Print Services
.s.f
.i -8;SYNOPSIS:
.s
.nf
 unsigned req;    /* Request Code */
 char *file       /* File name or "" */
 int *stat        /* --> 2-word status block */
.s
 p$cprnt(request, filespec, stat);
.s
.fill
.i -8;DESCRIPTION:
.s
Cprnt is a callable routine that allows your application to print a file,
stop, continue, abandon or restart a print job, or obtain printer status.
A request to print a file creates a non-interactive task.
.s
Request codes:
.nf
	+1 print file
	+2 abandon current print job
	+3 pause current print job
	+4 continue the paused print job
	+5 restart the current print job
	+6 report printer condition
.fill
.s
Remainder of the 75-word integer array is used as a temporary
scratch pad by the CPRNT routine
.s
For more information please refer to the Professional Developer's
Toolkit Reference Manual.
.s
.i -8;DIAGNOSTICS:
.s
The following codes may appear in the first word of the status array
.s
+1 -- Request accepted. If the request was "report printer condition",
the second word returns one of the decimal condition codes expounded
upon in the P/OS manual.
.pg
-1 -- Error occured. Second element of array contains DSW error codes.
.s
-21 --  Print service error occured. Second word contains decimal error
code explained in the manual.
.s
.i -8;AUTHOR:
.s
Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$dmenu#Display Dynamic Menu
.pg
.hl 1 ^&Display Dynamic Menu\&
.s 2
.c ;***********
.c ;* p$dmenu *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$dmenu -- Display Dynamic Menu
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *action;   /* --> buffer to receive action str */
 int maxlen;     /* Size of action string buffer */
 int addopt;     /* TRUE = enable additional opt's */
 char *msg1;     /* Message for line 23 or NULL */
 char *msg2;     /* Message for line 24 or NULL */
 int *stat;      /* --> 2 word status block */
.s
.fill
p$dmenu(action, maxlen, addopt, msg1, msg2, stat)
.s
.i -8;DESCRIPTION:
.s
p$dmenu displays the single-choice menu in the dynamic buffer.
It serves as the gateway to the dmenu directive in a standard C
library.
.s
For more information refer to the Professional Developer's
Toolkit Reference Manual.
.s
.i -8;AUTHOR:
.s
Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$dpack#Pack Dynamic Single-choice Menu
.pg
.hl 1 ^&Pack Dynamic Single-choice Menu\&
.s 2
.c ;***********
.c ;* p$dpack *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$dpack -- Pack Dynamic Single-choice Menu
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *fid;           /* Field ID */
 char *buf;           /* Field 'value' buffer */
 char *keyw;          /* "DFLT" or "KEYWnn" */
 int p1, p2;          /* Parameter(s) for above */
 int clear;           /* TRUE = clear dynamic buffer */
 int stat[2];         /* 2-word status */
.s
 p$dpack(fid, buf, keyw, p1, p2, clear, stat)
.s
.fill
.i -8;DESCIPTION:
.s
The p$dpack directive has restricted access: it handles only
one field, thus requires multiple calls.  It doesn't support
both 'DFLT' and 'KEYWnn' fields in the same call.
.s
The field ID, a string of six(max) uppercase characters, specifies
one of the following field identifiers:
.s
.nf
 FID	        nn          Menu Field
 ---            --          ----------
 'TITL'			    title
 'TEXTnn'     01,02,03      explanatory text
 'GHLP'		            global help frame identifier
 'PRMT'			    prompt text for line 21
 'OPTNnn'     01 - 12       option text for option nn
 'ACTNnn'     01 - 12       action string for option nn
 'OHLPnn'     01 - 12       help frame ID for option nn
.s
.fill
.i -8;DIAGNOSTICS:
.s
No error code will be returned if option help frame identifier
is specified with an invalid number.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$fatler########Fatal error
.pg
.hl 1 ^&Fatal error\&
.s 2
.c ;************
.c ;* p$fatler *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$fatler -- Fatal error
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *msg;
 p$fatler(msg)     	/* Message */
.s
.fill
.i -8;DESCRIPTION:
.s
The fatal error routine informs the user of an unexpected and
disabling error condition and returns control to P/OS (not your
task).  It blanks line 22, displays the message "Application
error.  Press RESUME to return to the Main Menu." on line 23, and
displays an application-defined message on line 24.  That message can
tell the user why the application failed and where to look for recovery
information.
.s
.i -8;AUTHOR:
.s
Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$getkey########Get Keystroke
.pg
.hl 1 ^&Get Keystroke\&
.s 2
.c ;************
.c ;* p$getkey *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$getkey -- Get Keystroke
.s.f
.i -8;SYNOPSIS:
.s
.nf
 int *stat;      /* 2-word status block */
.s
 p$getkey(stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$getkey directive gets a single keystroke from the terminal.
The keystroke is not echoed on the screen. POSRES.H contains
definitions for status/keycodes.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$hclose########Close Help File
.pg
.hl 1 ^&Close Help File\&
.s 2
.c ;************
.c ;* p$hclose *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$hclose -- Close Help File
.s.f
.i -8;SYNOPSIS:
.s
.nf
 int *stat;         /* 2-word status block */
.s
 p$hclose(stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$hclose directive closes the current help definition file.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$help##Display Help Frame
.pg
.hl 1 ^&Display Help Frame\&
.s 2
.c ;**********
.c ;* p$help *
.c ;**********
.s 2
.lm +8
.s.i -8;NAME:	p$help -- Display Help Frame
.s.f
.i -8;SYNOPSIS:
.nf
 char *frame;         /* New default frame ID or NULL */
 int *stat;           /* 2-word status block */
.s
 p$help(frame, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The help directive displays the default frame or a specified help frame.
.s
.i -8;DIAGNOSTICS:
.s
If you specify a non-existent help frame identifier, POSRES does not
return an error code in the status block.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$hfile#Open help file
.pg
.hl 1 ^&Open help file\&
.s 2
.c ;***********
.c ;* p$hfile *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$hfile -- Open help file
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *file;             /* Help file name */
 char *frame;            /* Default frame ID */
 int *stat;              /* 2-word status block */
.s
 p$hfile(file, frame, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$hfile directive opens the specified help definition file and
sets the default help frame. Only one file can be open at any time.
If another help file is open, p$hfile closes it before opening the
requested file.
.s
.i -8;DIAGNOSTICS:
.s
A default help frame must be supplied.  Failure to do so will result in
a fatal error.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$hframe########Display help frame
.pg
.hl 1 ^&Display help frame\&
.s 2
.c ;************
.c ;* p$hframe *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$hframe -- Display help frame
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *frame;            /* Frame ID */
 int *stat;              /* 2-word status block */
.s
 p$hframe(frame, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$hframe directive specifies the frame id of the frame to be
displayed when the help is requested.  This call does not
result in a display; it simply defines the default frame.  The help
frame definition file must be open before calling P$HFRAME.
.s
.i -8;DIAGNOSTICS:
.s
If a non-existent help frame identifier is specified, POSRES does not
return an error code in the status block.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$mclose########Close Menu File
.pg
.hl 1 ^&Close Menu File\&
.s 2
.c ;************
.c ;* p$mclose *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$mclose -- Close Menu File
.s.f
.i -8;SYNOPSIS:
.s
.nf
 int *stat;      /* 2-word status block */
.s
 p$mclose(stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$mclose directive closes the current help definition file.
.s
.i -8;AUTHOR:
.s
Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$menu##Display Single-Choice Menu
.pg
.hl 1 ^&Display Single-Choice Menu\&
.s 2
.c ;**********
.c ;* p$menu *
.c ;**********
.s 2
.lm +8
.s.i -8;NAME:	p$menu -- Display Single-Choice Menu
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *action;    /* --> buffer to receive action str */
 int maxlen;      /* Size of action string buffer */
 int addopt;      /* TRUE = enable additional opt's */
 char *msg1;      /* Message for line 23 or NULL */
 char *msg2;      /* Message for line 24 or NULL */
 int *stat;       /* --> 2 word status block */
.s
 p$menu(action, maxlen, addopt, msg1, msg2, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$menu directive displays a frame from the default static
menu buffer. To display the Additional Options flag and return control
to the user if he selects the Additional Options key, pass a non-zero
character in the addopt variable.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$mfile#Open Menu File
.pg
.hl 1 ^&Open Menu File\&
.s 2
.c ;***********
.c ;* p$mfile *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$mfile -- Open Menu File
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *file;      /* Name of menu file */
 int *stat;       /* 2-word status block */
.s
 p$mfile(file, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$mfile directive opens the specified menu definition file.
Only one menu file can be open at any time.  P$MFILE closes any open
menu file before opening the requested file.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$mframe########Read Menu Frame
.pg
.hl 1 ^&Read Menu Frame\&
.s 2
.c ;************
.c ;* p$mframe *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$mframe -- Read Menu Frame
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *frame;    /* Frame ID string */
 char *gblact;   /* Global action string buffer addr */
 int maxlen;     /* Size of global action buffer */
 int *stat;      /* Returned 2-word status */
.s
 p$mframe(frame, gblact, maxlen, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$mframe directive reads the specified menu frame into the static
menu buffer.  The menu definition file must be open before calling
P$MFRAME.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$mmenu#Show Multiple Choice Menu Frame
.pg
.hl 1 ^&Show Multiple Choice Menu Frame\&
.s 2
.c ;***********
.c ;* p$mmenu *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$mmenu -- Show Multiple Choice Menu Frame
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *optstr; /* Array of fixed-length option strs */
 int optlen;   /* Fixed length of option strings */
 int nopts;    /* Number of options */
 int lim;      /* Limit to number of selections */
 int *sels;    /* Returned array of selected options */
 int addopt;   /* TRUE = enable additional opt's */
 char *msg1;   /* Message for line 23 or NULL */
 char *msg2;   /* Message for line 24 or NULL */
 int *stat;    /* --> 2 word status block */
.s
 p$mmenu(optstr, optlen, nopts, lim, sels, addopt, msg1,
	 msg2, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$mmenu directive displays a multiple-choice menu. To display the
Additional Options flag and return control to the user if he selects
the Additional Options key, pass a non-zero character in the addopt
variable.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$mpack#Pack Multiple-Choice Menu
.pg
.hl 1 ^&Pack Multiple-Choice Menu\&
.s 2
.c ;***********
.c ;* p$mpack *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$mpack -- Pack Multiple-Choice Menu
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *fid;        /* Field ID */
 char *buf;        /* Field 'value' buffer */
 int clear;        /* TRUE = clear dynamic buffer */
 int stat[2];      /* 2-word status */
.s
 p$mpack(fid, buf, clear, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$mpack directive stores information in (packs) the multiple-choice
menu buffer. This routine has restricted access: it handles only one
field, thus requires multiple calls.  The field ID (FID), a string of
six (max) uppercase characters specifies one a the following field
identifiers:
.s
.nf
 FID	        nn          Menu Field
 ---            --          ----------
 'TITL'			    title
 'TEXTnn'     01,02,03      explanatory text
 'GHLP'		            global help frame identifier
 'PRMT'			    prompt text for line 21
.s
.s
.fill
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$msgbrd########Send Message to Message/Status Board
.pg
.hl 1 ^&Send Message to Message/Status Board\&
.s 2
.c ;************
.c ;* p$msgbrd *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$msgbrd -- Send Message to Message/Status Board
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *msg;     /* Message Board */
 int *stat;     /* 2-word status */
.s
 p$msgbrd(msg, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$msgbrd directive ssends a message to the P/OS Message/Status Board,
described in the Tool Kit User's Guide. This routine is not in POSRES; it is
in the system library (SYSLIB).
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$munpk#Unpack Menu Buffer
.pg
.hl 1 ^&Unpack Menu Buffer\&
.s 2
.c ;***********
.c ;* p$munpk *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$munpk -- Unpack Menu Buffer
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *fid;          /* Field ID */
 char *buf;          /* Field 'value' buffer */
 int maxl;           /* Value buffer size */
 char *keyw;         /* "DFLT" or "KEYWnn" */
 int *p1, *p2;       /* Parameter(s) for above */
 int stat[2];        /* 2-word status */
.s
 p$munpk(fid, buf, maxl, keyw, p1, p2, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$munpk directive unpacks(return information stored in) the static
menu buffer This has restricted access. It handles only one field, thus
requiring multiple calls.  Also, it doesn't support both 'DFLT' and 'KEYWnn'
fields in the same call.
.s
The field ID, a string of six(max) uppercase characters, specifies
one of the following field identifiers:
.s
.nf
 FID	        nn          Menu Field
 ---            --          ----------
 'TITL'			    title
 'TEXTnn'     01,02,03      explanatory text
 'GHLP'		            global help frame identifier
 'PRMT'			    prompt text for line 21
 'OPTNnn'     01 - 12       option text for option nn
 'ACTNnn'     01 - 12       action string for option nn
 'OHLPnn'     01 - 12       help frame ID for option nn
.s
.fill
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$newfil########Create a file menu
.pg
.hl 1 ^&Create a file menu\&
.s 2
.c ;************
.c ;* p$newfil *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$newfil -- Create a file menu
.s.f
.i -8;SYNOPSIS:
.s
.nf
 char *name;     /* In: default file name  */
		 /* Out: actual file specification */
 char *type;     /* In: default file type */
		 /* Out: new default file type  */
 char *text1;    /* Text at top of form or NULL */
 char *msg1;     /* Message on line 23 or NULL */
 int *stat;      /* 2-word status block */
.s
 p$newfil(name, type, text1, msg1, stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$newfil directive solicits the name of a new file to be
created by displaying the P/OS New File Specification form.
.s
.i -8;AUTHOR:
.s
.nf
 Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$oldfil########File Selection Menu
.pg
.hl 1 ^&File Selection Menu\&
.s 2
.c ;************
.c ;* p$oldfil *
.c ;************
.s 2
.lm +8
.s.i -8;NAME:	p$oldfil -- File Selection Menu
.s.f
.i -8;SYNOPSIS:
.s
.nf
 _#define NCHOICES xxx /* nchoice */
 char *wspec;         /* Wild file spec */
 int *nchoice;        /* Max allowed to select */
 char *fspecs;        /* Array of 50-byte spec bufs */
 char *text1;         /* Text at top of frame */
 char *msg1;          /* Message on line 23 */
 char *msg2;          /* Message on line 24 */
 int *stat;           /* 2-word status block */
.s
 p$oldfil(wspec, nchoice, fspecs, text1, msg1, msg2,
	 stat)
.s
.fill
.i -8;DESCRIPTION:
.s
The p$oldfil directive solicits the names of one or more existing
files by displaying the File Selection Menu.
.s
The default wild-card specification can be used by supplying a
zero-length string, in order to display the latest versions of
all files in the user's current directory.  The Additional Options
"show all versions" and "show only the latest versions" work only
when you use the default wild-card specifications Otherwise, the
same file selection menu will redisplay.
.s
The p$oldfil routine requires a static buffer, a multi-buffer, and a
file selection buffer.
.s
.i -8;AUTHOR:
.s
Bob Denny
.s
.lm 8.rm 72.nhy

.st ########p$wtres#Wait for Resume Key
.pg
.hl 1 ^&Wait for Resume Key\&
.s 2
.c ;***********
.c ;* p$wtres *
.c ;***********
.s 2
.lm +8
.s.i -8;NAME:	p$wtres -- Wait for Resume Key
.s.f
.i -8;SYNOPSIS:
.s
wtres()
.s
.i -8;DESCRIPTION:
.s
The p$wtres directive echoes all keystrokes except the RESUME key with
a bell character.  When the user presses the RESUME key, control
returns to your task.  You can use this routine to allow the user
to read something on the screen or change a diskette, for example,
before proceeding. Before calling WTRES, display a message such as
"Press RESUME to continue." on the screen.
.s
.i -8;AUTHOR:
.s
Bob Denny
.s
.lm 8.rm 72.nhy

